@@ -72,10 +72,10 @@ PALETTES = {
         '#FFFFFFFFFFFF:#D9D9E6E6F2F2:#0D0D19192626'
     ),
     'Bluloco': (
-        '#181818181818:#FFFF2E2E3F3F:#6F6FD7D75D5D:#FFFF6F6F2323:#23235151D9D9:'
-        '#98986161F8F8:#0000CDCDB3B3:#FFFFFCFCC2C2:#555557575353:#FFFF64648080:'
+        '#505050505050:#FFFF2E2E3F3F:#6F6FD6D65D5D:#FFFF6F6F2323:#34347676FFFF:'
+        '#98986161F8F8:#0000CDCDB3B3:#FFFFFCFCC2C2:#7C7C7C7C7C7C:#FFFF64648080:'
         '#3F3FC5C56B6B:#F9F9C8C85959:#0000B1B1FEFE:#B6B68D8DFFFF:#B3B38B8B7D7D:'
-        '#FFFFFEFEE3E3:#DEDEE0E0DFDF:#1E1E1E1E1E1E'
+        '#FFFFFEFEE3E3:#DEDEE0E0DFDF:#262626262626'
     ),
     'Borland': (
         '#4E4E4E4E4E4E:#FFFF6B6B6060:#A7A7FFFF6060:#FFFFFFFFB6B6:#9696CACAFDFD:'
@@ -185,6 +185,12 @@ PALETTES = {
         '#6060E0E06F6F:#D6D698982727:#7878D8D8D8D8:#CDCD7C7C5353:#5858D5D59898:'
         '#FFFFF1F1E8E8:#808079797373:#212121211C1C'
     ),
+    'Elementary Loki': (
+        '#070736364242:#DCDC32322F2F:#858599990000:#B5B589890000:#26268B8BD2D2:'
+        '#ECEC00004848:#2A2AA1A19898:#9494A3A3A5A5:#58586E6E7575:#CBCB4B4B1616:'
+        '#858599990000:#B5B589890000:#26268B8BD2D2:#D3D336368282:#2A2AA1A19898:'
+        '#EEEEEEEEEEEE:#9494A3A3A5A5:#25252E2E3232'
+    ),
     'Espresso Libre': (
         '#000000000000:#CCCC00000000:#1A1A92921C1C:#EFEFE4E43A3A:#00006666FFFF:'
         '#C5C565656B6B:#050598989A9A:#D3D3D7D7CFCF:#545457575353:#EFEF28282828:'
@@ -485,6 +491,30 @@ PALETTES = {
         '#0000D9D90000:#E5E5E5E50000:#00000000FFFF:#E5E50000E5E5:#0000E5E5E5E5:'
         '#E5E5E5E5E5E5:#FFFFFFFFFFFF:#22224F4FBCBC'
     ),
+    'Ocean Dark': (
+        '#2B2B30303B3B:#BFBF61616A6A:#A3A3BEBE8C8C:#EBEBCBCB8B8B:#8F8FA1A1B3B3:'
+        '#B4B48E8EADAD:#9696B5B5B4B4:#C0C0C5C5CECE:#656573737E7E:#BFBF61616A6A:'
+        '#A3A3BEBE8C8C:#EBEBCBCB8B8B:#8F8FA1A1B3B3:#B4B48E8EADAD:#9696B5B5B4B4:'
+        '#EFEFF1F1F5F5:#C0C0C5C5CECE:#2B2B30303B3B'
+    ),
+    'Ocean Light': (
+        '#EFEFF1F1F5F5:#BFBF61616A6A:#A3A3BEBE8C8C:#EBEBCBCB8B8B:#8F8FA1A1B3B3:'
+        '#B4B48E8EADAD:#9696B5B5B4B4:#C0C0C5C5CECE:#656573737E7E:#BFBF61616A6A:'
+        '#A3A3BEBE8C8C:#EBEBCBCB8B8B:#8F8FA1A1B3B3:#B4B48E8EADAD:#9696B5B5B4B4:'
+        '#2B2B30303B3B:#4F4F5B5B6666:#EFEFF1F1F5F5'
+    ),
+    'Oceanic Next Dark': (
+        '#1B1B2B2B3434:#ECEC5f5f6767:#9999C7C79494:#FAFAC8C86363:#66669999CCCC:'
+        '#C5C59494C5C5:#5F5FB3B3B3B3:#C0C0C5C5CECE:#656573737E7E:#ECEC5f5f6767:'
+        '#9999C7C79494:#FAFAC8C86363:#66669999CCCC:#C5C59494C5C5:#5F5FB3B3B3B3:'
+        '#D8D8DEDEE9E9:#C0C0C5C5CECE:#1B1B2B2B3434'
+    ),
+    'Oceanic Next Light': (
+        '#D8D8DEDEE9E9:#ECEC5f5f6767:#9999C7C79494:#FAFAC8C86363:#66669999CCCC:'
+        '#C5C59494C5C5:#5F5FB3B3B3B3:#C0C0C5C5CECE:#656573737E7E:#ECEC5f5f6767:'
+        '#9999C7C79494:#FAFAC8C86363:#66669999CCCC:#C5C59494C5C5:#5F5FB3B3B3B3:'
+        '#1B1B2B2B3434:#4F4F5B5B6666:#D8D8DEDEE9E9'
+    ),
     'Ollie': (
         '#000000000000:#ABAB2E2E3030:#3131ABAB6060:#ABAB42420000:#2C2C5656ABAB:'
         '#AFAF84842727:#1F1FA5A5ABAB:#8A8A8D8DABAB:#5A5A36362525:#FFFF3D3D4848:'
